#
# spec file for package gtksourceview
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtksourceview
Version:        3.24.11
Release:        lp152.2.5
Summary:        GTK+ Source Editing Widget
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/GtkSourceView
Source0:        http://download.gnome.org/sources/gtksourceview/3.24/%{name}-%{version}.tar.xz
Source1:        changes.lang
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel >= 1.42.0
BuildRequires:  itstool
BuildRequires:  libxml2-devel >= 2.6
BuildRequires:  pkgconfig
BuildRequires:  translation-update-upstream
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= 2.48
BuildRequires:  pkgconfig(gladeui-2.0) >= 3.9
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(valgrind)

%description
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%package -n libgtksourceview-3_0-1
Summary:        GTK+ Source Editing Widget
Group:          System/Libraries
Provides:       gtksourceview = %{version}
Obsoletes:      gtksourceview < %{version}

%description -n libgtksourceview-3_0-1
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%package -n typelib-1_0-GtkSource-3_0
Summary:        Introspection bindings for the GTK+ source editing widget
Group:          System/Libraries

%description -n typelib-1_0-GtkSource-3_0
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

This package provides the GObject Introspection bindings for
GtkSourceView.

%package -n glade-catalog-gtksourceview
Summary:        Glade catalog for the GTK+ source editing widget
Group:          Development/Tools/GUI Builders
Requires:       glade
Requires:       libgtksourceview-3_0-1 = %{version}
Supplements:    packageand(glade:%{name}-devel)

%description -n glade-catalog-gtksourceview
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

This package provides a catalog for Glade, to allow the use the
GtkSourceView widget in Glade.

%package devel
Summary:        Development files for the GTK+ source editing widget
Group:          Development/Languages/C and C++
Requires:       gtksourceview = %{version}
Requires:       typelib-1_0-GtkSource-3_0 = %{version}

%description devel
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%lang_package

%prep
%setup -q
translation-update-upstream

%build
%configure \
        --disable-static \
        --enable-glade-catalog \
        --disable-gtk-doc
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}-3.0
# Install language definition for *.changes files:
install -m 644 %{S:1} %{buildroot}%{_datadir}/gtksourceview-3.0/language-specs/
%fdupes %{buildroot}%{_datadir}

%post -n libgtksourceview-3_0-1 -p /sbin/ldconfig
%postun -n libgtksourceview-3_0-1 -p /sbin/ldconfig

%files -n libgtksourceview-3_0-1
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/libgtksourceview-3.0.so.*
%{_datadir}/gtksourceview-3.0/

%files -n typelib-1_0-GtkSource-3_0
%{_libdir}/girepository-1.0/GtkSource-3.0.typelib

%files -n glade-catalog-gtksourceview
%{_datadir}/glade/catalogs/gtksourceview.xml

%files devel
%doc ChangeLog MAINTAINERS
%{_includedir}/gtksourceview-3.0/
%{_libdir}/libgtksourceview-3.0.so
%{_libdir}/pkgconfig/gtksourceview-3.0.pc
%{_datadir}/gir-1.0/GtkSource-3.0.gir
%{_datadir}/gtk-doc/html/gtksourceview-3.0/
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gtksourceview-3.0.*

%files lang -f %{name}-3.0.lang

%changelog
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue May  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.11:
  + Improvements to the syntax highlighting of: YAML, Julia, C++,
    and C.
  + Fixes to GObject Introspection annotations.
  + Fix a crash with YAML.
  + Fix a crash in presense of Byte-Order-Markers.
* Sat Mar 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.10:
  + New syntax highlighting definition file for: Powershell.
  + Improvements to the syntax highlighting of: reStructuredText,
    C++, CSS, HTML, Groovy, Meson, Python3, and Logtalk.
  + Fix testsuite for changes in GLib hashtable ordering.
  + Avoid double entry of languages based on globs.
  + MSVC build improvements.
  + Fix usage of GRegex for offset in text, which fixes a Valgrind
    warning.
  + Ensure CSS is inherted from parent style schemes.
  + Avoid storing GtkTextIter across main-loop boundaries.
  + Fix incorrect transfer annoation for
    gtk_source_buffer_create_source_mark().
  + Various memory leak fixes.
  + Updated translations.
* Thu Sep  6 2018 bjorn.lie@gmail.com
- Update to version 3.24.9:
  + New syntax highlighting definition file for: Logtalk.
  + Improvements to the syntax highlighting of: Haskell, C++, GLSL,
    and Markdown.
  + Performance improvements to space drawing.
  + Missing G_PARAM_DEPRECATED flag was added to :underline
    property.
  + Various memory leak fixes.
  + Updated translations.
* Thu Aug 16 2018 luc14n0@linuxmail.org
- Add changes.lang language definition for changes file syntax
  highlighting capabilities.
* Sun Jun 17 2018 bjorn.lie@gmail.com
- Update to version 3.24.8:
  + MS Windows: lib shutdown on DLL_PROCESS_DETACH,
    not DLL_THREAD_DETACH.
  + Syntax highlighting: sync all *.lang files from GtkSourceView4.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Mar 14 2018 luc14n0@linuxmail.org
- Update to version 3.24.7:
  + GtkSourceView class: respect the GtkTextView:accepts-tab
    property.
  + Syntax highlighting: sync all *.lang files from GtkSourceView
    4.
  + Updated translations.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
- Conditionalize translation-update-upstream BuildRequires,
  a SLE-only requirement.
* Mon Mar  5 2018 jengelh@inai.de
- Remove ineffective --with-pic. Fix RPM groups.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Dec  9 2017 zaitor@opensuse.org
- Update to version 3.24.6:
  + New syntax highlighting definition file for: logcat.
  + Improvements to the syntax highlighting of: Python and
    reStructuredText.
  + Improvements to the Visual Studio builds.
  + Updated translations.
* Mon Oct  2 2017 luc14n0@linuxmail.org
- Update to version 3.24.5:
  + Bug fix in gtk_source_view_indent_lines().
  + Improvements to the:
  - Visual Studio builds.
  - Syntax highlighting of: Vala.
  + Updated translations.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 3.24.4:
  + Fix bug when GtkSourceView:indent-width and :tab-width are
    equal.
  + New syntax highlighting definition files for: Swift, Maxima and
    Kotlin.
  + Various other small improvements.
  + Updated translations.
* Sun Jun 18 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Improvements to the syntax highlighting of: SPARQL, CSS, BibTeX
    and LaTeX.
* Mon May 22 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Avoid type redefinitions.
  + jade.lang: add *.pug to globs.
  + Bug fix in LaTeX syntax highlighting.
  + Various other small bug fixes.
  + Updated translations.
* Mon Apr 10 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Deprecate the 'copy' parameter of the GtkSourceView::move-lines
    signal.
  + Force visual word movements for RTL text with Ctrl+left/right.
  + Misc bug fixes.
  + Updated translations.
* Sun Mar 19 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Sun Mar 12 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Improvements to the Visual Studio builds and add support for
    Visual Studio 2017.
  + Bug fix in Rust syntax highlighting.
  + Add mimetype to python3.lang.
  + Updated translations.
* Wed Feb 15 2017 zaitor@opensuse.org
- Update to version 3.23.90:
  + Bug fix in GtkSourceGutterRendererPixbuf.
  + Fixes for bugs found by Coverity.
  + New syntax highlighting definition file for: Django template.
  + Improvements to the syntax highlighting of: CSS and JavaScript.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Docs: add an introduction with the pkg-config name and which
    GTK+ version is used.
  + Build fixes on MS Windows.
  + New syntax highlighting definition files for: ABNF and HAXE.
  + Improvements to the syntax highlighting of: JavaScript, PHP,
    Meson, CSS, ini and Rust.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + New class: GtkSourceSpaceDrawer with a matrix property to
    combine space types vs locations. The old white space drawing
    API has been deprecated.
  + gtk_source_search_context_set_settings() has been deprecated,
    the "settings" property will become construct-only.
  + GtkSourceCompletionItem: add a new API and deprecate the old
    constructors.
  + GtkSourceGutter: add get_view() and get_window_type() public
    functions.
  + Build system: do not hardcode the API version (currently 3.0)
    at as many places as possible (use a variable instead).
  + Bug fixes.
  + Documentation improvements.
  + Updated translations.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.22.2:
  + Build fixes on Windows.
* Sun Nov  6 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Bug fix in gtk_source_buffer_sort_lines().
  + Fixes in the win32 MSVC build.
  + Updated translations.
* Sun Sep 18 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Sat Sep 10 2016 zaitor@opensuse.org
- Update to version 3.21.6:
  + Improvements to the syntax highlighting of: CSS and Rust.
  + Updated translations.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.21.5:
  + Fix an infinite loop in whitespace drawing.
  + Updated translations.
* Sun Aug 14 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + GtkSourceRegion:
  - Add functions to add/subtract/intersect two GtkSourceRegions.
  - Rename functions to add/subtract/intersect a subregion.
  - Real unit tests.
  + Whitespace drawing: draw a final newline if the
    GtkSourceBuffer:implicit-trailing-newline property is TRUE.
  + Whitespace drawing: refactor the code, move the code to a
    private SpaceDrawer class.
  + Use gconstructor.h to have a DSO constructor that inits i18n,
    and a destructor to unref the singletons.
  + Use the AX_VALGRIND_CHECK Autotools macro.
  + SearchContext: send a private signal to the views so that the
    views can ask the SearchContext to highlight in priority the
    visible areas of the buffer (works only for normal search, not
    regex search).
  + Improvements to the syntax highlighting of: LaTeX.
  + Various other code improvements.
  + Updated translations.
- Add pkgconfig(valgrind) BuildRequires: Build the new valgrind
  support.
- Drop anchient gtksourceview-doc Provides/Obsoletes: No longer any
  supported openSUSE release with this package.
* Sun Jul 17 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Warn when a secondary public header is #included in external
    code.  Only <gtksourceview/gtksource.h> should be #included
    directly.
  + Remove the --disable-completion-providers configure option, to
    always build the completion providers. There is currently only
    one completion provider: GtkSourceCompletionWords, which is not
    a lot of code and doesn't pull up additional dependencies.
  + Add back the gtksourceview-typebuiltins.h public header, for
    backward compatibility.
  + Fixes/improvements to the Visual Studio builds.
  + Improvements to the syntax highlighting of: rpmspec.
  + Fix a bug in GtkSourceSearchContext.
  + Various small code and documentation improvements.
  + Updated translations.
* Wed Jun 22 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Make gtk_source_style_apply() public.
  + GtkSourceSearchContext: add "version 2" of some functions to
    improve the API, and deprecate the v1's.
  + Fix a critical message when showing a completion window.
  + Fix a drawing issue with syntax highlighting.
  + Improvements to the syntax highlighting of: Meson, JavaScript.
  + Various code improvements and bug fixes.
  + Documentation improvements.
  + Build fixes on ARM.
* Wed Jun 22 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Export SourceRegion in the public API.
  + Updated translations.
* Wed Jun 22 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Fix a critical message when showing a completion window.
  + Fix a general syntax highlighting issue.
  + Other smaller bug fixes.
  + Updated translations.
* Thu May 19 2016 tyang@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Sun May  8 2016 badshah400@gmail.com
- Update to version 3.20.3:
  + Improvements to the Meson and JavaScript syntax highlighting.
  + Small bug fixes.
  + Updated translations.
* Sat Apr 23 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Drawing optimizations.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Mar 30 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Improvements to style schemes.
  + Export missing public methods.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Improvements to the syntax highlighting of: CSS, JavaScript,
    protobuf, Vala, imagej, Python 3 and BibTeX.
  + Adapt code to use GTK_TEXT_VIEW_LAYER_BELOW_TEXT and
    GTK_TEXT_VIEW_LAYER_ABOVE_TEXT.
  + Add a "sourceview" CSS class to all GtkSourceView's.
  + Fixes to the MSVC build system.
  + Various other small fixes and improvements.
  + Updated translations.
* Wed Jan 20 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + CSS fixes to track GTK+ changes.
  + Fix completion popup on Wayland.
  + MSVC build projects.
  + Misc bug fixes.
  + Updated translations.
* Thu Jan 14 2016 zaitor@opensuse.org
- Update to version 3.19.3:
  + Many fixes to track GTK+ changes.
  + Rework symbol visibility handling.
  + Other small improvements.
  + Updated translations.
* Thu Jan 14 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Some CSS adjustments to track GTK+ changes.
  + Add API to get the GtkSourceView version.
  + Other small improvements.
  + Updated translations.
* Thu Jan 14 2016 zaitor@opensuse.org
- Update to version 3.19.1:
  + New class: GtkSourceTag with a draw-spaces property.
  + Drop build dependency on intltool, use upstream gettext and
    ITS Tool instead.
  + Completion windows: don't add space for scrollbars.
  + Do not show undo/redo in context menu if undo/redo is disabled.
  + Bracket matching: several bug fixes, unit tests written, code
    simplified.
  + Other small code improvements.
  + Updated translations.
- Replace intltool for itstool BuildRequres following upstream
  codechange.
* Thu Jan 14 2016 dimstar@opensuse.org
- Update to version 3.18.2:
  + A few bug fixes in *.lang files.
  + Updated translations.
* Sun Oct 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Misc bug fixes.
  + Updated translations.
* Sun Sep 20 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Minor improvement to the CSS syntax highlighting.
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.7:
  + Handle creating pixbufs for HiDPI resolutions.
  + Improvements to the Octave and Matlab syntax highlighting.
  + Other various code improvements.
  + Updated translations.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.6:
  + Search and replace: fix bug with regular expressions containing
    look-ahead assertions.
  + Add some missing GI annotations.
  + A few adjustments to the build system.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.5:
  + Support symbolic icons in the completion API.
  + New lang or improved lang files: Rust, Meson, C, protobuf.
  + Revamped build system (drop gnome-common dependency).
  + Misc bug fixes.
  + Updated translations.
* Mon Jul 20 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Add .rej files as another version of diff file.
  + Improvements to lang files: Apache Pig, rpmspec.
  + Misc bug fixes.
  + Updated translations.
* Thu Jun 25 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Add a few more functions to GtkSourceFile.
  + Add the "smart-backspace" property.
  + Misc bug fixes.
  + Updated translations.
* Tue May 26 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + New widget: GtkSourceMap.
  + Set a GtkTextTag name for context classes (no-spell-check,
    etc).
  + Add gtk_source_buffer_sort_lines().
  + Style schemes:
  - Support "single", "double" etc for the underline attribute.
  - Support underline-color.
  + Improvements to lang files: Ocaml, C++ header and Shell.
  + Updated translations.
* Thu Apr 30 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + New public API: gtk_source_encoding_get_default_candidates().
  + Add g_autoptr autocleanup support.
  + Add lang files for (basic) CSV and jade template.
  + Improvements to lang files: C, CMake, GDB log, JavaScript, C#,
    F#, VB.net and CSS.
  + Updated translations.
* Sun Apr 12 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Update CMake language spec.
  + Add a "path" class for contexts with a file name.
  + Performance improvements for groups of text
    insertions/deletions.
  + Fix bug with symbolic icons and dark GTK+ theme.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + A few bug fixes and various other improvements.
  + Updated translations.
* Fri Mar  6 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Fix a crash when destroying the widget during a search.
  + Add some signals to bind keyboard actions.
  + Various other improvements.
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Provide a way to draw background patterns (a grid).
  + Support incrementing and decrementing numbers.
  + Various other improvements.
* Mon Jan 19 2015 badshah400@gmail.com
- Update to version 3.15.3:
  + Better word boundaries for word selection (double-click) and
    word movements (ctrl+arrow, shift+ctrl+arrow, ctrl+backspace,
    etc).
  + Add style scheme chooser widgets: GtkSourceStyleSchemeChooser
    (interface), GtkSourceStyleSchemeChooserButton and
    GtkSourceStyleSchemeChooserWidget.
  + Add gtk_source_view_indent_lines() and
    gtk_source_view_unindent_lines().
  + Add the GtkSourceView::move-to-matching-bracket action signal.
  + Add gtk_source_buffer_join_lines().
  + Gutter: use current line background color for current line.
  + Add syntax highlighting support for Apache Thrift.
  + Various other improvements and bug fixes.
  + Updated translations.
* Thu Jan  8 2015 zaitor@opensuse.org
- Update to version 3.15.2:
  + Undo/Redo: restore selection.
  + Documentation improvements.
  + Some GtkSourceGutter code refactoring.
  + Syntax highlighting for Apache Pig 0.12.
* Thu Jan  8 2015 zaitor@opensuse.org
- Update to version 3.15.1:
  + Search: allow caller to choose a style for text matches.
  + gtk_source_completion_context_get_iter() now returns a gboolean
    to tell if the GtkTextIter is correctly set. For a more robust
    code, it is recommended to use the return value.
  + Improvements to the Lua and Yacc syntax highlighting.
  + Updated translations.
* Wed Jan  7 2015 zaitor@opensuse.org
- Update to version 3.14.3:
  + Bug fixes.
  + Updated translations.
* Sun Nov  9 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Bug fix.
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Fix UndoManager with a new implementation.
  + Various other improvements.
  + Updated translations.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Improved Mac OS X support.
  + Gutter improvements.
  + Various other improvements and code clean-up.
  + Updated translations.
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Adjustments to the file loading and saving API:
  - Make gtk_source_encoding_get_default_candidates() private.
  - Replace gtk_source_encoding_foreach() by
    gtk_source_encoding_get_all().
  + Add Vala bindings.
  + Various other improvements.
  + Updated translations.
- Add vala BuildRequires: new dependency to build the vala
  bindings.
- Set devel package group to "Development/Languages/C and C++".
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Extend the api to obtain candidate encodings.
  + Rework drawing of spaces and margins (requires new Gtk+).
  + Various other improvements and bugfixes.
  + Updated translations.
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + New feature: file loading and saving.
  + Split testfiles.sh to tests/syntax-highlighting/.
  + GtkSourceView is now fully relicensed to LGPL.
  + Various other improvements and bugfixes.
  + Updated translations.
- Update License to LGPL-2.1+, following upstreams relicensing
  efforts.
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.1:
  + Improvements to the words completion provider.
  + Completion window sizing fixes.
  + Improvements to some lang files.
  + Various other improvements and bugfixes.
  + Updated translations.
* Wed Aug 20 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Misc bugfixes.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Misc bugfixes.
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Renovate test-widget.
  + Various improvements and bugfixes.
  + Updated translations.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Small improvements to the documentation.
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Add syntax highlighting for LLVM IR and Sweave.
  + Improvements to some lang files.
  + Updated translations.
* Thu Feb  6 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Add the popular Solarized style schemes.
  + Improvements to some lang files and a new lang file for lex.
  + Optimize the draw-spaces code.
  + Various fixes to the completion framework.
  + Misc bugfixes.
  + Updated translations.
* Thu Jan 30 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Font scaling support for headings/titles in LaTeX and HTML.
  + Add Change Case submenu to the right click context menu.
  + Add ANS Forth 94 syntax highlighting.
  + Misc bugfixes.
  + Updated translations.
- Update URL Tag to match configure.ac.
* Wed Jan 29 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Add API to change text case.
  + Add reStructuredText and yaml syntax highlighting.
  + Improve LaTeX, m4 and D syntax highlighting.
  + Documentation improvements (including best practices for
    language definition files).
  + Installed tests.
  + Misc bugfixes.
  + Updated translations.
* Tue Jan 28 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Deprecate the Gutter:xpad and Gutter:ypad properties.
  + Deprecate gtk_source_gutter_get_window().
  + Better implementation of GtkSourceMarks (private class
    GtkSourceMarksSequence).
  + Style schemes: more visible right margin.
  + Documentation improvements.
  + Misc bugfixes.
  + Updated translations.
* Mon Jan 27 2014 dimstar@opensuse.org
- Update to version 3.10.2:
  + Various bugfixes.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Various bugfixes.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Small bugfix.
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + SearchSettings: change default value of wrap-around to FALSE.
  + Misc bugfixes.
  + Updated translations.
- Drop gtksourceview-mm-buildfix.patch: fixed upstream.
* Mon Sep  9 2013 dimstar@opensuse.org
- Add gtksourceview-mm-buildfix.patch: Use the expected typedef for
  GtkSourceStyleClass.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Improvements to the completion.
  + API break for the search and replace.
  + Deprecate the GtkSourceMarkAttributes:stock-id property.
  + Misc bugfixes.
  + Updated translations.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Modify the search and replace API: SearchContext and
    SearchSettings classes.
  + Regular expression search.
  + Misc bugfixes.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Warning: the search and replace API is unstable.
  + Misc bugfixes.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Add a higher-level asynchronous search and replace API.
  + Deprecate gtk_source_completion_item_new_from_stock().
  + Deprecate the GtkSourceGutterRendererPixbuf:stock-id property.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + dd syntax highlighting for the Julia, mediawiki and Scala
    languages.
  + Improvements to the word completion provider.
  + Add the GtkSourceCompletionWords:activation property.
  + More compact completion popup window.
  + Misc bugfixes.
  + Updated translations.
- Drop gtksourceview-as-needed.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh, as
  we no longer carry any patch.
* Mon May 27 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Deprecate the GtkSourceCompletionInfo::before-show signal.
  + Hide CompletionInfo when focus-out-event on the attached-to
    widget.
  + Improvements to the main completion window.
  + Some code improvements to the words completion provider.
  + Improvements to the C++ and Perl language specs.
  + Documentation improvements.
  + Misc bugfixes.
  + Updated translations.
- Add gtksourceview-as-needed.patch: Fix build with
  - Wl,--as-needed.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Improvements to the LaTeX and Perl language specs.
  + Update to gtk-mac-integration 2.0 API.
  + More unit tests.
  + Misc bugfixes.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Add Libtool versioning. There was an ABI break during this
    development cycle, because some private functions were
    accidentally exported. So the Libtool's -version-info is bumped
    from 0:0:0 to 1:0:0. On GNU/Linux, this results in a version
    bump of the soname.
  + Updated translations.
- rename libgtksourceview-3_0-0 subpackage to
  libgtksourceview-3_0-1, following upstreams soname bump.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + New style id for warnings.
  + Improvements to the completion code and documentation.
  + Misc bugfixes.
  + Updated translations.
- Add pkgconfig(glib-2.0) BuildRequires: new, explicitly tested
  dependency.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Simplify code for the completion.
  + Improvements of the Perl, R and Ruby language specs.
  + Misc bugfixes.
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Improvements in completion.
  + Add Modelica language spec.
  + Misc bugfixes.
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Deprecate gtk_source_completion_move_window().
  + Deprecate gtk_source_completion_info_get_widget().
  + Deprecate gtk_source_completion_info_set_widget().
  + CompletionInfo: always a natural size.
  + Simplify internal code for the completion (new CompletionModel)
  + Fixes for the style schemes and GtkSourceMark.
  + Other misc bugfixes.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Improved unit tests and code coverage support.
  + Misc bugfixes.
  + Updated translations.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Add Bluespec SystemVerilog syntax highlighter.
  + Improvements in completion.
  + Add language spec for IDL.
  + Lots of fixes in gtk doc.
  + Misc bugfixes.
  + Updated translations.
* Mon Nov  5 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fixed important invalid write
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.4:
  + Misc bugfixes.
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + New ActionScript, mxml and J languages
  + Misc bugfixes
  + Updated translations.
* Sun Jul 29 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Misc bugfixes
- Changes from version 3.5.1:
  + New puppet language
  + Improvements in Go language
  + Misc bugfixes
  + Updated translations.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Improvements to completion code
  + Misc bugfixes
  + Updated translations.
- Add explicit pkgconfig(gio-2.0) BuildRequires so it can be
  versioned.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Fix problems with the completion popup when headers are hidden
  + Misc bugfixes
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Misc bugfixes.
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Misc bugfixes.
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Python3 lang file.
  + Win32 build fixes.
  + Misc bugfixes.
  + Updated translations.
* Sun Jan  8 2012 zaitor@opensuse.org
- Update to version 3.3.2:
  + Introduce gtk_source_language_get_style_fallback.
  + Refactoring and cleanup.
  + Misc bugfixes.
  + Updated translations.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.1:
  + Change IgeMacIntegration to GtkOSXApplication
  + Allow for multiple GDK backends
  + Sort schemes alphabetically
  + Sort the languages alphabetically
  + Misc bugfixes
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GtkSource-3_0 subpackage.
- Add typelib-1_0-GtkSource-3_0 Requires to devel subpackage.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.3:
  + Misc bugfixes.
  + Updated translations.
* Sun Oct 16 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Misc bugfixes.
* Sun Oct  9 2011 zaitor@opensuse.org
- Update to version 3.2.1:
  + New JavaScript Object Notation lang file.
  + Improvements to some of the lang files.
  + Misc bugfixes.
  + Updated translations.
* Wed Oct  5 2011 vuntz@opensuse.org
- Re-enable the build of the glade catalog (bnc#689575):
  + Remove the enable_glade_catalog define that was set to 0.
  + Change libgladeui-1_0-devel BuildRequires to
    pkgconfig(gladeui-2.0).
  + Rename glade3-catalog-gtksourceview subpackage to
    glade-catalog-gtksourceview since it's a catalog for glade, and
    not glade3.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.6:
  + New Automake lang file
  + New protobuf lang file
  + Misc bugfixes
  + Updated translations
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.5:
  + Misc bugfixes
  + Updated translations
* Tue Aug  9 2011 dimstar@opensuse.org
- Update to version 3.1.4:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + New Markdown lang file
  + New Standard ML lang file
  + Misc bugfixes
  + Updated translations
* Tue Jun 14 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + Misc bugfixes
  + Updated translations.
* Sat Jun  4 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Fri May 27 2011 dimstar@opensuse.org
- Update to version 3.0.3:
  + Improvements to some of the lang files
  + Misc bugfixes.
* Wed May 25 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Improvements to some of the lang files.
  + Misc bugfixes.
  + Updated translations.
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
- Changes from version 2.91.9:
  + Use the GTK_SOURCE_ prefix also for all the macros
- Changes from version 2.91.8:
  + Misc bugfixes
- Changes from versions 2.91.7 / 2.91.6:
  + Misc bugfixes
- Changes from version 2.91.5:
  + Improvements to some of the lang files
  + Misc bugfixes
- Changes from version 2.91.4:
  + Highlight C standard streams and signals
  + GtkSourceView is not a factory of categories now
  + Fix style problems
  + Improvements to some of the lang files
  + Misc bugfixes
- Changes from version 2.91.3:
  + Improvements to some of the lang files
  + Misc bugfixes
- Changes from version 2.91.2:
  + Improved Gutter support
  + New languages: Cobol, GO, Scilab
  + Misc bugfixes
- Changes from version 2.91.1:
  + Removed SourceIter, caseless search is now in gtk
  + Adapt to latest gtk changes
  + Misc bugfixes
- Changes from version 2.91.0:
  + Added SystemVerilog language
  + Improvements to some of the lang files
  + Misc bugfixes
- Changes from version 2.90.4:
  + Improvements to some of the lang files
  + Misc bugfixes
- Changes from version 2.90.3:
  + Bump version to 2.90: we are now targeting gtk3.
    This release is parallel installable with GtkSourveView 2
  + Misc bugfixes
- Disable glade3 catalog support with the enable_glade_catalog
  macro, as we don't have the gtk3 version of glade yet.
- Change gtk2-devel BuildRequires to pkgconfig(gtk+-3.0).
- Add gobject-introspection-devel BuildRequires to enable
  introspection support.
- Rename libgtksourceview-2_0-0 to libgtksourceview-3_0-0 following
  soname change.
- Remove explicit Requires for gtk2-devel and libxml2-devel in
  devel package: they will automatically be added the pkgconfig()
  way.
* Tue Oct  5 2010 vuntz@opensuse.org
- Split glade3 catalog in a glade3-catalog-gtksourceview
  subpackage. Part of bnc#637694.
- Update summaries and descriptions.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.10.5:
  + Updated translations.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.10.4:
  + Misc bugfixes
  + Updated translations
- Changes from version 2.10.3:
  + Misc bugfixes
  + Updated translations
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.10.1:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Sun Mar 28 2010 vuntz@opensuse.org
- Update to version 2.10.0:
  + Misc bugfixes
  + Updated translations.
* Tue Mar 23 2010 vuntz@opensuse.org
- Pass --enable-glade-catalog to configure and add
  libgladeui-1_0-devel BuildRequires to get the glade3 catalog.
* Wed Mar 17 2010 dimstar@opensuse.org
- Update to version 2.9.9:
  + Distribute a catalog for glade3
  + Misc bugfixes
  + Updated translations.
* Wed Mar  3 2010 dimstar@opensuse.org
- Update to version 2.9.8:
  + Bugfixes in the "words" completion provider
  + Misc bugfixes
  + Updated translations
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 2.9.7:
  + Remove a leftover in the UndoManager API
- Changes from version 2.9.6:
  + Changes to the completion API to allow better language bindings
  + Add API to set a custom UndoManager on the buffer
  + Misc bugfixes
  + Updated translations
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.9.5:
  + Misc bugfixes
  + Translation updates
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.9.4:
  + Implement context classes and use them to mark strings,
    comments, keywords and regions where spell-check is disabled
  + More work on completion
  + Improvements to some of the lang files
  + Misc bugfixes
  + Translation updates
- sed line that removed gconf-2.0 in configure is no longer needed
* Mon Dec  7 2009 vuntz@opensuse.org
- Remove en@shaw workaround.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.9.3:
  + Crasher bugfixes in word completion provider
  + Misc bugfixes for win32
  + Smarter autoindentation
  + New language: SPARQL
  + Misc bugfixes
  + Updated translations
- Changes from version 2.9.2:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
- Changes from version 2.9.1:
  + Added draw spaces for leading, text and trailing spaces
  + Merged GtkSourceCompletion branch
  + Updated translations
- Remove check for gconf-2.0 added by mistake to configure.
* Tue Sep 29 2009 vuntz@opensuse.org
- Update to version 2.8.1:
  + Misc bugfixes in gutter tooltip rendering
  + Updated translations
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 2.8.0:
  + Misc bugfixes
  + Updated translations
* Wed Sep 16 2009 lmedinas@opensuse.org
- Update to version 2.7.5:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 2.7.4:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Wed Jul 29 2009 vuntz@novell.com
- Remove unneeded update-desktop-files BuildRequires.
* Tue Jul 28 2009 lmedinas@gmail.com
- Update to version 2.7.3:
  + Misc bugfixes
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 2.7.2:
  + Add GtkSourceGutter api to customize gutter drawing
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.7.1:
  + Add tooltips to GtkSourceMarks
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Mon May 18 2009 vuntz@novell.com
- Update to version 2.6.2:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Wed Apr 15 2009 vuntz@novell.com
- Remove empty gtksourceview package and instead move the README,
  etc. files to libgtksourceview-2_0-0. This package also
  obsoletes/provides gtksourceview.
- Add gtksourceview Requires to the devel package (it should be
  libgtksourceview-2_0-0 strictly speaking, but we avoid a rpmlint
  warning this way).
* Sun Apr 12 2009 mboman@suse.de
- Update to version 2.6.1:
  + Improvements to some of the lang files
  + Translation updates
- Remove AutoReqProv. It's default
- Remove Requires libgtksourceview-2_0-0 from main package
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 2.6.0:
  + Improvements to some of the lang files
  + Updated translations
- Remove BuildRequires: gnome-common, libglade2-devel.
- Add BuildRequires: gtk2-devel, libxml2-devel.
- Use --disable-gtk-doc in configure since we don't need to
  regenerate the doc.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.5.6:
  + Misc bugfixes
  + Updated translations
- Add back libxml2-devel to requires of devel package to fix many
  build breaks.
- Remove -fno-strict-aliasing from CFLAGS.
- Remove AutoReqProv: it's default now.
* Sat Feb 28 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies, libxml2-devel not needed here.
* Tue Feb 17 2009 mboman@suse.de
- Fix Provides/Obsoletes for gtksourceview-doc.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Feb 15 2009 mboman@suse.de
- Update to version 2.5.5:
  + New "cobalt" style scheme
  + Misc bugfixes
  + Updated translations
- Move gtk-doc to -devel packages
* Thu Feb  5 2009 mboman@suse.de
- Update to version 2.5.4:
  + Improvements to some of the lang files
  + Translation updates
* Mon Feb  2 2009 mboman@suse.de
- Update to version 2.5.3:
  + Improvements to some of the lang files
  + Translation updates
* Sun Jan 25 2009 vuntz@novell.com
- Remove useless BuildRequires.
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.5.2:
  + Misc bugfixes
  + Improvements to some of the lang files
  + Translation updates
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.5.1:
  + Misc bugfixes
  + Improvements to some of the lang files
  + Translation updates
* Wed Dec 24 2008 mboman@suse.de
- Update to version 2.4.1:
  + Fix a crash when inserting images in the buffer
  + Improvements to some of the lang files
  + Translation updates
* Sun Sep 21 2008 mboman@suse.de
- Update to version 2.4.0:
  + Updated translations
* Fri Sep 12 2008 maw@suse.de
- Update to version 2.3.3:
  + Improvements to some of the lang files
  + Updated translations.
* Mon Sep  1 2008 mboman@novell.com
- Update to version 2.3.2:
  + Misc bugfixes
  + Improvements to some of the lang files
  + Updated translations
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.3.1:
  + Add function to guess the language for a given filename and
    mime type; accordingly, bump the glib dependency to 2.14, which
    includes gio, and remove the gnome-vfs dep
  + Allow setting the background color of paragraphs with marks
  + Support drawing white spaces
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Wed Aug  6 2008 maw@suse.de
- Update to version 2.2.2:
  + Improvements to some language files
  + Misc. bugfixes
  + Updated translations.
* Wed Apr  9 2008 maw@suse.de
- Update to version 2.2.1:
  + Improve keybindings
  + Misc. bugfixes
  + Updated translations.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.2.0:
  + Misc bugfixes
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.1.3:
  + Misc. bugfixes
  + Updated translations.
* Mon Feb 18 2008 maw@suse.de
- Update to version 2.1.2:
  + Fix a GtkSourceMark API issue
  + Updated translations.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.1.0:
  + New gtk-print based printing API
  + New GtkTextMark based GtkSourceMark API
  + Misc bugfixes
  + Updated translations.
* Mon Sep 17 2007 maw@suse.de
- Update to version 2.0.0:
  + Updated translations.
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.4:
  + Many improvements in all the lang files
  + Minor API tweaks
  + Misc bugfixes
  + Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage.
* Thu Aug  2 2007 maw@suse.de
- Update to version 1.90.3:
  + API breakage as of version 1.90.0
  + New highlighting and theming engine
  + GnomePrint-based print API removal
  + GtkSourceStyle is now a gobject
  + Port to GRegex
  + Support replacing contexts
  + Support symbolic colors in schemes
  + Add tango style scheme
  + Improvements for programming language description files,
    particularly those for ruby and perl
  + Updated translations
  + Misc bugfixes
- Use %%fdupes
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun
- Concomitant with the API breakage, create a
  libgtksourceview-2_0-0 subpackage.
* Fri Mar 30 2007 maw@suse.de
- Update to version 1.8.5
  - updated translations
* Thu Mar  8 2007 maw@suse.de
- Update to version 1.8.4, which brings:
- RPM highlighting (Konstantin Ryabitsev)
- Fix a problem with search in accented words (Yevgen Muntyan)
- Misc lang file fixes
- Updated translations
* Wed Jan  3 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 1.8.1
- Fixed #357447 – Missing break in gtk_source_tag_set_property()
- Fixed #357746 – "Insert spaces instead of tabs" doesn't work
- Updated translations
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 1.8.0
- Added text/x-gettext-translation-template to the list of
  mime-types in po.lang
- Updated translations
* Tue Aug 15 2006 jhargadon@suse.de
- update to version 1.7.2
- add an 'indent-on-tab' property
- highlight fortran operators
- Updated translations
- Consume all button press events on the line numbers margin
* Wed Aug  2 2006 danw@suse.de
- intltoolize before autoreconf'ing to avoid version skew between
  configure macros and po/Makefile.in.in
* Mon Feb  6 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 1.5.6.
* Wed Nov 30 2005 wberrier@suse.de
- Update to 1.5.1
* Thu Oct 13 2005 gekker@suse.de
- Update to version 1.4.2
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 1.4.1.
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 1.4.0.
* Tue Aug 23 2005 gekker@suse.de
- Update to version 1.3.92
* Thu Aug 11 2005 gekker@suse.de
- Update to version 1.3.91
* Fri Jul 22 2005 gekker@suse.de
- Update to version 1.2.1
* Tue Apr 26 2005 ke@suse.de
- The -devel subpackage requires libxml2-devel, gtk2-devel, and
  libgnomeprint-devel; reported by Ben Maurer [#80398].
* Wed Mar  9 2005 gekker@suse.de
- Update to version 1.2.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 1.1.93
* Fri Feb 11 2005 gekker@suse.de
- Update to version 1.1.92
* Tue Jan 25 2005 clahey@suse.de
- Updated to version 1.1.91.
* Tue Jan 18 2005 clahey@suse.de
- Updated to version 1.1.90.
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Wed May  5 2004 sbrabec@suse.cz
- Updated to version 1.0.1 (GNOME 2,6).
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 0.7.0.
* Fri Oct 10 2003 sbrabec@suse.cz
- Fixed docdir ownership.
* Thu Oct  9 2003 sbrabec@suse.cz
- Added new SuSE package, version 0.6.0 (GNOME 2.4).
